@@ -1,9 +1,12 @@
 from asyncio import run
-from sys import stderr
+from sys import exit, stderr
 
 from .server.main import main
 
 try:
-    run(main())
+    code = run(main())
 except KeyboardInterrupt:
     stderr.close()
+    exit(130)
+else:
+    exit(code)
